# PiPy Version 
[![PyPI version](https://badge.fury.io/py/inforion.svg)](https://badge.fury.io/py/inforion)

(https://img.shields.io/pypi/wheel/inforion)
# Current Build Status

[![Build Status](https://dev.azure.com/InforOS/InforION/_apis/build/status/dajor.inforion?branchName=master)](https://dev.azure.com/InforOS/InforION/_build/latest?definitionId=2&branchName=master)



inforion -u https://mingle-sso.eu1.inforcloudsuite.com:443/Fellow_DEV -f FellowKey.ionapi -m CRS610bulk -i newoutput.xlsx -o outF6F.xlsx


[![Documentation Status](https://readthedocs.org/projects/inforion/badge/?version=latest)](https://inforion.readthedocs.io/de/latest/?badge=latest)

More infor [Fellow Consulting AG](https://www.fellow-consulting.com/)

![Python package](https://github.com/dajor/inforion/workflows/Python%20package/badge.svg)

[![CodeFactor](https://www.codefactor.io/repository/github/dajor/inforion/badge/master)](https://www.codefactor.io/repository/github/dajor/inforion/overview/master)

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/51dc66d4b0664f708f3e2480e7ec7b42)](https://www.codacy.com/manual/daniel.jordan/inforion?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=dajor/inforion&amp;utm_campaign=Badge_Grade)